import React, { FC, ReactNode } from 'react';
import { DimensionValue, Modal as ReactModal, View } from 'react-native';
import { ModalHeader } from './ModalHeader/modal-header';
import { styles } from './style';

type Props = {
  children: ReactNode;
  visible: boolean;
  onRequestClose?: () => void;
  visibleInPercent?: DimensionValue;
  headerTitle: string;
};

export const Modal: FC<Props> = ({
  children,
  onRequestClose,
  visible,
  visibleInPercent,
  headerTitle
}) => {
  return (
    <ReactModal
      animationType={'slide'}
      statusBarTranslucent={true}
      presentationStyle={'pageSheet'}
      visible={visible}
      onRequestClose={onRequestClose}
      transparent={true}
    >
      <View
        style={[
          styles.wrapper,
          {
            height: visibleInPercent ?? '100%',
            borderTopLeftRadius: visibleInPercent ? 10 : 0,
            borderTopRightRadius: visibleInPercent ? 10 : 0
          }
        ]}
      >
        <ModalHeader onRequestClose={onRequestClose} textHeader={headerTitle} />
        <Drawer />
        {children}
      </View>
    </ReactModal>
  );
};

const Drawer = () => {
  return <View style={styles.drawer} />;
};
